/* ----------------------------------------------------------------
 * haninit.c 
 *
 *	Provides a default version of the Tcl_AppInit procedure for
 *	use in wish and similar Tk-based applications.
 *
 *		Created by EunJa Kim. (POSTECH KLE Lab.)
 *		1994.
 */

#include "Config.h"
#include "tcl.h"
#include "tk.h"

#include <string.h>
#include "H_define.h"

extern hinput_InitAutomata ();

extern char hinput_state;

/*
 * The following variable is a special hack that allows applications
 * to be linked using the procedure "main" from the Tk library.  The
 * variable generates a reference to "main", which causes main to
 * be brought in from the library (and all of Tk and Tcl with it).
 */

int InitAutomataCmd (ClientData clientData, Tcl_Interp *interp, int argc, char *argv[])
{
	if (argc != 1) {
		interp->result = "wrong number of arguments\n";
		return TCL_ERROR;
	}

	if (hinput_InitAutomata ()) {
		sprintf (interp->result, "%s", "TCK_OK");
		return TCL_OK;
	} else {
		sprintf (interp->result, "%s", "Init Error");
		return TCL_OK;
	}
}


int hinput_Roma2han(char *input, char *output);

int Roma2hanCmd(ClientData clientData, Tcl_Interp *interp, int argc, char *argv[])
{
	char output[256];
    
	if (argc != 3) {
		interp->result = "wrong number of arguments\n";
		return TCL_ERROR;
	}
    
	if (hinput_state == qS)
		sprintf (interp->result, "%s", argv[1]);

	hinput_Roma2han(argv[2][0], output);

	if( strlen(output) > 0 )
		strcat (interp->result, output);

	return TCL_OK;

}


/*
 *----------------------------------------------------------------------
 *
 * Han_Init --
 *
 *	This procedure performs application-specific initialization.
 *	Most applications, especially those that incorporate additional
 *	packages, will have their own version of this procedure.
 *
 * Results:
 *	Returns a standard Tcl completion code, and leaves an error
 *	message in interp->result if an error occurs.
 *
 * Side effects:
 *	Depends on the startup script.
 *
 *----------------------------------------------------------------------
 */

int
Han_Init(interp)
    Tcl_Interp *interp;		/* Interpreter for application. */
{
    /*
     * Call Tcl_CreateCommand for application-specific commands, if
     * they weren't already created by the init procedures called above.
     */

    Tcl_CreateCommand(interp, "InitHanAutomata", InitAutomataCmd,
		      (ClientData *) NULL,
		      (Tcl_CmdDeleteProc *) NULL);

    Tcl_CreateCommand(interp, "Romaji2Han", Roma2hanCmd,
		      (ClientData *) NULL,
		      (Tcl_CmdDeleteProc *) NULL);

	Tcl_Eval(interp, HENTRY);
	Tcl_Eval(interp, HTEXT);
    /*
     * Specify a user-specific startup file to invoke if the application
     * is run interactively.  Typically the startup file is "~/.apprc"
     * where "app" is the name of the application.  If this line is deleted
     * then no user-specific startup file will be run under any conditions.
     */

    return TCL_OK;
}





